@@ -86,6 +86,9 @@ FAILEDOPERATION_REFUNDSOURCEPACKAGEERROR = 'FailedOperation.RefundSourcePackageE
 # 修改策略失败。
 FAILEDOPERATION_SERVERLESSSETSTRATEGYERROR = 'FailedOperation.ServerlessSetStrategyError'
 
+# 规格信息{{1}}搜索失败
+FAILEDOPERATION_SPECNOTFOUNDERROR = 'FailedOperation.SpecNotFoundError'
+
 # 创建并支付订单失败，请稍后重试。如果持续不成功，请联系客服进行处理。
 FAILEDOPERATION_TRADECREATEORDERERROR = 'FailedOperation.TradeCreateOrderError'
 
@@ -266,6 +269,9 @@ OPERATIONDENIED_CLUSTEROPNOTALLOWEDERROR = 'OperationDenied.ClusterOpNotAllowedE
 # 集群当前状态不允许该操作。
 OPERATIONDENIED_CLUSTERSTATUSDENIEDERROR = 'OperationDenied.ClusterStatusDeniedError'
 
+# 获取proxy失败
+OPERATIONDENIED_GETPROXYGROUPFAILEDERROR = 'OperationDenied.GetProxyGroupFailedError'
+
 # 您没有权限操作资源。
 OPERATIONDENIED_INSTANCEACCESSDENIEDERROR = 'OperationDenied.InstanceAccessDeniedError'
 
@@ -278,6 +284,30 @@ OPERATIONDENIED_INSTANCESTATUSLIMITERROR = 'OperationDenied.InstanceStatusLimitE
 # 账号余额不足。
 OPERATIONDENIED_INSUFFICIENTBALANCEERROR = 'OperationDenied.InsufficientBalanceError'
 
+# 您没有权限操作该资源（进行该操作）。
+OPERATIONDENIED_OPERATIONDENIEDERROR = 'OperationDenied.OperationDeniedError'
+
+# 暂停状态的serverless不允许修改多可用区。
+OPERATIONDENIED_PAUSEDSLSNOTALLOWMODIFYSLAVE = 'OperationDenied.PausedSlsNotAllowModifySlave'
+
+# proxy节点支持的可创建的连接数量不匹配,可支持的创建连接数{{1}},当前连接数{{2}}
+OPERATIONDENIED_PROXYCONNECTCOUNTCHECKERROR = 'OperationDenied.ProxyConnectCountCheckError'
+
+# 代理节点数量检查失败
+OPERATIONDENIED_PROXYNODECOUNTCHECKERROR = 'OperationDenied.ProxyNodeCountCheckError'
+
+# 非运行的proxy
+OPERATIONDENIED_PROXYNOTRUNNINGERROR = 'OperationDenied.ProxyNotRunningError'
+
+# 可用区不存在
+OPERATIONDENIED_PROXYSALEZONECHECKERROR = 'OperationDenied.ProxySaleZoneCheckError'
+
+# 代理版本检查失败
+OPERATIONDENIED_PROXYVERSIONCHECKERROR = 'OperationDenied.ProxyVersionCheckError'
+
+# proxy可用区校验失败
+OPERATIONDENIED_PROXYZONECHECKERROR = 'OperationDenied.ProxyZoneCheckError'
+
 # serverless集群当前状态不允许该操作。
 OPERATIONDENIED_SERVERLESSCLUSTERSTATUSDENIED = 'OperationDenied.ServerlessClusterStatusDenied'
 
